@@ -7,7 +7,7 @@ from tensorfn.util.config import (
 )
 from tensorfn.util.ensure import ensure_tuple
 from tensorfn.util.lazy_extension import LazyExtension
-from tensorfn.util.logger import setup_logger, create_small_table
+from tensorfn.util.logger import get_logger, create_small_table
 
 
 def load_wandb():
